<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2010 Arno Dudek <webmaster@adgrafik.at>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Google Maps API class.
 * Nearly the same like the Google Maps API
 * @see http://code.google.com/apis/maps/documentation/javascript/reference.html
 *
 * @version $Id:$
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License, version 2
 * @package Extbase
 * @subpackage GoogleMapsAPI\MarkerImage
 * @scope prototype
 * @entity
 * @api
 */
class Tx_AdGoogleMaps_Api_MarkerImage {

	/**
	 * @var string
	 */
	protected $url;

	/**
	 * @var Tx_AdGoogleMaps_Api_Size
	 */
	protected $size;

	/**
	 * @var Tx_AdGoogleMaps_Api_Point
	 */
	protected $origin;

	/**
	 * @var Tx_AdGoogleMaps_Api_Point
	 */
	protected $anchor;

	/**
	 * @var Tx_AdGoogleMaps_Api_Size
	 */
	protected $scaledSize;

	/*
	 * Constructor.
	 * 
	 * @param string $url
	 * @param Tx_AdGoogleMaps_Api_Size $size
	 * @param Tx_AdGoogleMaps_Api_Point $origin
	 * @param Tx_AdGoogleMaps_Api_Point $anchor
	 * @param Tx_AdGoogleMaps_Api_Size $scaledSize
	 */
	public function __construct($url, Tx_AdGoogleMaps_Api_Size $size = NULL, Tx_AdGoogleMaps_Api_Point $origin = NULL, Tx_AdGoogleMaps_Api_Point $anchor = NULL, Tx_AdGoogleMaps_Api_Size $scaledSize = NULL) {
		$this->url = $url;
		$this->size = $size;
		$this->origin = $origin;
		$this->anchor = $anchor;
		$this->scaledSize = $scaledSize;
	}

	/**
	 * Sets this url.
	 *
	 * @param string $url
	 * @return void
	 */
	public function setUrl($url) {
		$this->url = $url;
	}

	/**
	 * Returns this url.
	 *
	 * @return string
	 */
	public function getUrl() {
		return $this->url;
	}

	/**
	 * Sets this size.
	 *
	 * @param Tx_AdGoogleMaps_Api_Size $size
	 * @return Tx_AdGoogleMaps_Api_MarkerImage
	 */
	public function setSize(Tx_AdGoogleMaps_Api_Size $size) {
		$this->size = $size;
		return $this;
	}

	/**
	 * Returns this size.
	 *
	 * @return integer
	 */
	public function getSize() {
		return $this->size;
	}

	/**
	 * Sets this origin.
	 *
	 * @param Tx_AdGoogleMaps_Api_Point $origin
	 * @return Tx_AdGoogleMaps_Api_MarkerImage
	 */
	public function setOrigin(Tx_AdGoogleMaps_Api_Point $origin) {
		$this->origin = $origin;
		return $this;
	}

	/**
	 * Returns this origin.
	 *
	 * @return Tx_AdGoogleMaps_Api_Point
	 */
	public function getOrigin() {
		return $this->origin;
	}

	/**
	 * Sets this anchor.
	 *
	 * @param Tx_AdGoogleMaps_Api_Point $anchor
	 * @return Tx_AdGoogleMaps_Api_MarkerImage
	 */
	public function setAnchor(Tx_AdGoogleMaps_Api_Point $anchor) {
		$this->anchor = $anchor;
		return $this;
	}

	/**
	 * Returns this anchor.
	 *
	 * @return Tx_AdGoogleMaps_Api_Point
	 */
	public function getAnchor() {
		return $this->anchor;
	}

	/**
	 * Sets this scaledSize.
	 *
	 * @param Tx_AdGoogleMaps_Api_Size $scaledSize
	 * @return Tx_AdGoogleMaps_Api_MarkerImage
	 */
	public function setScaledSize($scaledSize) {
		$this->scaledSize = $scaledSize;
		return $this;
	}

	/**
	 * Returns this scaledSize.
	 *
	 * @return Tx_AdGoogleMaps_Api_Size
	 */
	public function getScaledSize() {
		return $this->scaledSize;
	}

	/**
	 * Returns the marker image as JavaScript string.
	 *
	 * @return string
	 */
	public function getPrint() {
		return ($this->url !== '' ? sprintf('new google.maps.MarkerImage(\'%s\', %s, %s, %s, %s)', $this->url, $this->size, $this->origin, $this->anchor, $this->scaledSize) : 'null');
	}

	/**
	 * Returns the marker image as JavaScript string.
	 *
	 * @return string
	 */
	public function __toString() {
		return $this->getPrint();
	}

}

?>